@@ -19,9 +19,9 @@ __all__ = [
 ]
 
 __package_name__ = 'python-statsd'
-__version__ = '1.6.2'
+__version__ = '1.6.3'
 __author__ = 'Rick van Hattem'
-__author_email__ = 'Rick.van.Hattem@Fawo.nl'
+__author_email__ = 'Wolph@wol.ph'
 __description__ = (
     '''statsd is a client for Etsy's node-js statsd server. '''
     '''A proxy for the Graphite stats collection and graphing server.''')
